summaryrefslogtreecommitdiff
path: root/hw/usb/hid-logitech-dj.c
diff options
context:
space:
mode:
Diffstat (limited to 'hw/usb/hid-logitech-dj.c')
-rw-r--r--hw/usb/hid-logitech-dj.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/hw/usb/hid-logitech-dj.c b/hw/usb/hid-logitech-dj.c
index f01a4f312f..5f1bc80f56 100644
--- a/hw/usb/hid-logitech-dj.c
+++ b/hw/usb/hid-logitech-dj.c
@@ -487,8 +487,8 @@ static void hidpp_handle_hid(USBDevice *dev, USBPacket *p)
for (i = 0; i < MAX_DEVICES; i++) {
LHidDevice *hd = &s->devices[i];
- /* ignore empty slots and unreachable devices */
- if (!hd->info.device_type || !hd->powered_on) {
+ /* ignore empty slots and unreachable/HID mode devices */
+ if (!hd->info.device_type || !hd->powered_on || hd->mode != LTUNIFY_MODE_DJ) {
continue;
}